==> nextcloud-11.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files/l10n/zh_CN.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "存储空间暂时不可用",
    "Storage invalid" : "存储空间无效",
    "Unknown error" : "未知错误",
    "All files" : "全部文件",
    "Recent" : "最近",
    "File could not be found" : "文件未找到",
    "Home" : "首页",
    "Close" : "关闭",
    "Favorites" : "收藏",
    "Could not create folder \"{dir}\"" : "无法创建文件夹 \"{dir}\"",
    "Upload cancelled." : "上传已取消",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "无法上传文件 {filename}，因为它是一个目录或者是大小为 0 的空文件",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "可用空间不足，您上传的文件大小为 {size1} ，但可用空间仅剩 {size2}",
    "Target folder \"{dir}\" does not exist any more" : "目标目录 \"{dir}\" 不存在",
    "Not enough free space" : "可用空间不足",
    "Uploading..." : "正在上传...",
    "..." : "...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} / {totalSize} ({bitrate})",
    "Actions" : "操作",
    "Download" : "下载",
    "Rename" : "重命名",
    "Move" : "移动",
    "Target folder" : "目标目录",
    "Delete" : "删除",
    "Disconnect storage" : "断开存储链接",
    "Unshare" : "取消共享",
    "Could not load info for file \"{file}\"" : "无法加载文件 \"{file}\" 的信息",
    "Files" : "文件",
    "Details" : "详细信息",
    "Select" : "选择",
    "Pending" : "等待",
    "Unable to determine date" : "无法确定日期",
    "This operation is forbidden" : "操作被禁止",
    "This directory is unavailable, please check the logs or contact the administrator" : "此目录不可用, 请检查日志或联系管理员",
    "Could not move \"{file}\", target exists" : "无法移动 \"{file}\", 目标已存在",
    "Could not move \"{file}\"" : "无法移动 \"{file}\"",
    "{newName} already exists" : "{newname} 已经存在",
    "Could not rename \"{fileName}\", it does not exist any more" : "无法重命名 \"{fileName}\", 此文件已经不存在",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "文件夹 \"{dir}\" 中已经存在 \"{targetName}\". 请尝试其他的名称.",
    "Could not rename \"{fileName}\"" : "无法重命名 \"{fileName}\"",
    "Could not create file \"{file}\"" : "无法创建文件 \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "无法创建文件 \"{file}\"， 因为其已经存在",
    "Could not create folder \"{dir}\" because it already exists" : "无法创建文件夹 \"{dir}\"， 因为其已经存在",
    "Error deleting file \"{fileName}\"." : "删除文件 \"{fileName}\" 时出错.",
    "No search results in other folders for {tag}{filter}{endtag}" : "在其它的文件夹里没有关于{tag}{filter}{endtag}的搜索结果",
    "Name" : "名称",
    "Size" : "大小",
    "Modified" : "修改日期",
    "_%n folder_::_%n folders_" : ["%n 个文件夹"],
    "_%n file_::_%n files_" : ["%n 个文件"],
    "{dirs} and {files}" : "{dirs} 和 {files}",
    "_including %n hidden_::_including %n hidden_" : ["包括 %n 个隐藏文件"],
    "You don’t have permission to upload or create files here" : "您没有权限在此上传或创建文件",
    "_Uploading %n file_::_Uploading %n files_" : ["上传 %n 个文件"],
    "New" : "新建",
    "\"{name}\" is an invalid file name." : "\"{name}\" 是一个无效的文件名",
    "File name cannot be empty." : "文件名不能为空.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" 不是允许的文件类型",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "{owner} 的存储空间已满, 文件将无法更新或同步!",
    "Your storage is full, files can not be updated or synced anymore!" : "您的存储空间已满, 文件将无法更新或同步!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "{owner} 的存储空间即将用完 ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "您的存储空间即将用完 ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["匹配 '{filter}'"],
    "View in folder" : "在文件夹中查看",
    "Path" : "路径",
    "_%n byte_::_%n bytes_" : ["%n 字节"],
    "Favorited" : "已收藏",
    "Favorite" : "收藏",
    "Folder" : "文件夹",
    "New folder" : "新建文件夹",
    "Upload" : "上传",
    "An error occurred while trying to update the tags" : "更新标签时出错",
    "Added to favorites" : "添加到收藏",
    "Removed from favorites" : "取消收藏",
    "You added {file} to your favorites" : "您已经添加 {file} 到您的收藏夹",
    "You removed {file} from your favorites" : "您已从收藏夹中删除 {file}",
    "File changes" : "文件发生变化",
    "Created by {user}" : "由 {user} 创建",
    "Changed by {user}" : "由 {user} 更改",
    "Deleted by {user}" : "由 {user} 删除",
    "Restored by {user}" : "由 {user} 恢复",
    "Renamed by {user}" : "由 {user} 重命名",
    "Moved by {user}" : "由 {user} 移动",
    "You created {file}" : "您创建了 {file}",
    "{user} created {file}" : "{user} 创建了 {file}",
    "{file} was created in a public folder" : "{file} 被创建在公共文件夹",
    "You changed {file}" : "您更改了 {file}",
    "{user} changed {file}" : "{user} 更改了 {file}",
    "You deleted {file}" : "您删除了{file}",
    "{user} deleted {file}" : "{user} 删除了 {file}",
    "You restored {file}" : "您恢复了{file}",
    "{user} restored {file}" : "{user} 恢复了 {file}",
    "You renamed {oldfile} to {newfile}" : "您将 {oldfile} 改名为 {newfile}",
    "{user} renamed {oldfile} to {newfile}" : "{user} 将 {oldfile} 改名为 {newfile}",
    "You moved {oldfile} to {newfile}" : "您移动 {oldfile} 到 {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} 移动 {oldfile} 到 {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "文件已经添加或删除到您的 <strong>收藏夹</strong> 中",
    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "文件/文件夹已经 <strong>更改</strong> 或者 <strong>重命名</strong>",
    "A new file or folder has been <strong>created</strong>" : "新的文件/文件夹已经 <strong>创建</strong>",
    "A new file or folder has been <strong>deleted</strong>" : "新的文件/文件夹已经 <strong>删除</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "仅限 <strong>收藏文件</strong>的创建和更改通知 <em>(仅限流)</em>",
    "A new file or folder has been <strong>restored</strong>" : "新的文件/文件夹已经<strong>恢复</strong>",
    "Upload (max. %s)" : "上传 (最大 %s)",
    "File handling" : "文件处理",
    "Maximum upload size" : "最大上传大小",
    "max. possible: " : "最大允许: ",
    "Save" : "保存",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "对于 PHP-FPM 这个值改变后可能需要 5 分钟才会生效.",
    "Missing permissions to edit from here." : "没有权限编辑",
    "Settings" : "设置",
    "Show hidden files" : "显示隐藏文件",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "使用这个地址 <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">通过 WebDAV 访问您的文件</a>",
    "No files in here" : "无文件",
    "Upload some content or sync with your devices!" : "上传或从您的设备中同步!",
    "No entries found in this folder" : "文件夹中无项目",
    "Select all" : "全部选择",
    "Upload too large" : "上传文件过大",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "正在上传的文件超过了此服务器允许上传的最大容量限制",
    "Files and folders you mark as favorite will show up here" : "收藏的文件和文件夹会在这里显示",
    "Shared with you" : "与您分享",
    "Shared with others" : "与他人分享",
    "Shared by link" : "通过链接分享",
    "Tags" : "标签",
    "Deleted files" : "已删除的文件",
    "Text file" : "文本文件",
    "New text file.txt" : "创建文本文件 .txt",
    "_{hours}:{minutes}:{seconds} hour left_::_{hours}:{minutes}:{seconds} hours left_" : ["剩余 {hours}:{minutes}:{seconds} 小时"],
    "{hours}:{minutes}h" : "{hours}:{minutes}",
    "_{minutes}:{seconds} minute left_::_{minutes}:{seconds} minutes left_" : ["剩余 {minutes}:{seconds} 分钟"],
    "{minutes}:{seconds}m" : "{minutes}:{seconds}",
    "_{seconds} second left_::_{seconds} seconds left_" : ["剩余 {seconds} 秒"],
    "{seconds}s" : "{seconds}s",
    "Any moment now..." : "现在任何时候...",
    "Soon..." : "很快...",
    "File upload is in progress. Leaving the page now will cancel the upload." : "文件正在上传中. 离开此页将会取消上传.",
    "Copy local link" : "复制本地链接",
    "No favorites" : "无收藏"
},
"nplurals=1; plural=0;");

==> nextcloud-12.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files/l10n/zh_CN.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "存储空间暂时不可用",
    "Storage invalid" : "存储空间无效",
    "Unknown error" : "未知错误",
    "All files" : "全部文件",
    "Recent" : "最近",
    "File could not be found" : "文件未找到",
    "Home" : "首页",
    "Close" : "关闭",
    "Favorites" : "收藏",
    "Could not create folder \"{dir}\"" : "无法创建文件夹 \"{dir}\"",
    "Upload cancelled." : "上传已取消",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "无法上传文件 {filename}，因为它是一个目录或者是大小为 0 的空文件",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "可用空间不足，您上传的文件大小为 {size1} ，但可用空间仅剩 {size2}",
    "Target folder \"{dir}\" does not exist any more" : "目标目录 \"{dir}\" 不存在",
    "Not enough free space" : "可用空间不足",
    "Uploading..." : "正在上传...",
    "..." : "...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} / {totalSize} ({bitrate})",
    "Actions" : "操作",
    "Download" : "下载",
    "Rename" : "重命名",
    "Move" : "移动",
    "Target folder" : "目标目录",
    "Delete" : "删除",
    "Disconnect storage" : "断开存储链接",
    "Unshare" : "取消共享",
    "Could not load info for file \"{file}\"" : "无法加载文件 \"{file}\" 的信息",
    "Files" : "文件",
    "Details" : "详细信息",
    "Select" : "选择",
    "Pending" : "等待",
    "Unable to determine date" : "无法确定日期",
    "This operation is forbidden" : "操作被禁止",
    "This directory is unavailable, please check the logs or contact the administrator" : "此目录不可用, 请检查日志或联系管理员",
    "Could not move \"{file}\", target exists" : "无法移动 \"{file}\", 目标已存在",
    "Could not move \"{file}\"" : "无法移动 \"{file}\"",
    "{newName} already exists" : "{newname} 已经存在",
    "Could not rename \"{fileName}\", it does not exist any more" : "无法重命名 \"{fileName}\", 此文件已经不存在",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "文件夹 \"{dir}\" 中已经存在 \"{targetName}\". 请尝试其他的名称.",
    "Could not rename \"{fileName}\"" : "无法重命名 \"{fileName}\"",
    "Could not create file \"{file}\"" : "无法创建文件 \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "无法创建文件 \"{file}\"， 因为其已经存在",
    "Could not create folder \"{dir}\" because it already exists" : "无法创建文件夹 \"{dir}\"， 因为其已经存在",
    "Error deleting file \"{fileName}\"." : "删除文件 \"{fileName}\" 时出错.",
    "No search results in other folders for {tag}{filter}{endtag}" : "在其它的文件夹里没有关于{tag}{filter}{endtag}的搜索结果",
    "Name" : "名称",
    "Size" : "大小",
    "Modified" : "修改日期",
    "_%n folder_::_%n folders_" : ["%n 个文件夹"],
    "_%n file_::_%n files_" : ["%n 个文件"],
    "{dirs} and {files}" : "{dirs} 和 {files}",
    "_including %n hidden_::_including %n hidden_" : ["包括 %n 个隐藏文件"],
    "You don’t have permission to upload or create files here" : "您没有权限在此上传或创建文件",
    "_Uploading %n file_::_Uploading %n files_" : ["上传 %n 个文件"],
    "New" : "新建",
    "\"{name}\" is an invalid file name." : "\"{name}\" 是一个无效的文件名",
    "File name cannot be empty." : "文件名不能为空.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" 不是允许的文件类型",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "{owner} 的存储空间已满, 文件将无法更新或同步!",
    "Your storage is full, files can not be updated or synced anymore!" : "您的存储空间已满, 文件将无法更新或同步!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "{owner} 的存储空间即将用完 ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "您的存储空间即将用完 ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["匹配 '{filter}'"],
    "View in folder" : "在文件夹中查看",
    "Path" : "路径",
    "_%n byte_::_%n bytes_" : ["%n 字节"],
    "Favorited" : "已收藏",
    "Favorite" : "收藏",
    "Copy direct link (only works for users who have access to this file/folder)" : "复制直接链接(仅适用于有权访问此文件/文件夹的用户)",
    "New folder" : "新建文件夹",
    "Upload file" : "上传文件",
    "An error occurred while trying to update the tags" : "更新标签时出错",
    "Added to favorites" : "添加到收藏",
    "Removed from favorites" : "取消收藏",
    "You added {file} to your favorites" : "您已经添加 {file} 到您的收藏夹",
    "You removed {file} from your favorites" : "您已从收藏夹中删除 {file}",
    "File changes" : "文件发生变化",
    "Created by {user}" : "由 {user} 创建",
    "Changed by {user}" : "由 {user} 更改",
    "Deleted by {user}" : "由 {user} 删除",
    "Restored by {user}" : "由 {user} 恢复",
    "Renamed by {user}" : "由 {user} 重命名",
    "Moved by {user}" : "由 {user} 移动",
    "You created {file}" : "您创建了 {file}",
    "{user} created {file}" : "{user} 创建了 {file}",
    "{file} was created in a public folder" : "{file} 被创建在公共文件夹",
    "You changed {file}" : "您更改了 {file}",
    "{user} changed {file}" : "{user} 更改了 {file}",
    "You deleted {file}" : "您删除了{file}",
    "{user} deleted {file}" : "{user} 删除了 {file}",
    "You restored {file}" : "您恢复了{file}",
    "{user} restored {file}" : "{user} 恢复了 {file}",
    "You renamed {oldfile} to {newfile}" : "您将 {oldfile} 改名为 {newfile}",
    "{user} renamed {oldfile} to {newfile}" : "{user} 将 {oldfile} 改名为 {newfile}",
    "You moved {oldfile} to {newfile}" : "您移动 {oldfile} 到 {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} 移动 {oldfile} 到 {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "文件已经添加或删除到您的 <strong>收藏夹</strong> 中",
    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "文件/文件夹已经 <strong>更改</strong> 或者 <strong>重命名</strong>",
    "A new file or folder has been <strong>created</strong>" : "新的文件/文件夹已经 <strong>创建</strong>",
    "A new file or folder has been <strong>deleted</strong>" : "新的文件/文件夹已经 <strong>删除</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "仅限 <strong>收藏文件</strong>的创建和更改通知 <em>(仅限流)</em>",
    "A new file or folder has been <strong>restored</strong>" : "新的文件/文件夹已经<strong>恢复</strong>",
    "Upload (max. %s)" : "上传 (最大 %s)",
    "File handling" : "文件处理",
    "Maximum upload size" : "最大上传大小",
    "max. possible: " : "最大允许: ",
    "Save" : "保存",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "对于 PHP-FPM 这个值改变后可能需要 5 分钟才会生效.",
    "Missing permissions to edit from here." : "没有权限编辑",
    "Settings" : "设置",
    "Show hidden files" : "显示隐藏文件",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "使用这个地址 <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">通过 WebDAV 访问您的文件</a>",
    "No files in here" : "无文件",
    "Upload some content or sync with your devices!" : "上传或从您的设备中同步!",
    "No entries found in this folder" : "文件夹中无项目",
    "Select all" : "全部选择",
    "Upload too large" : "上传文件过大",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "正在上传的文件超过了此服务器允许上传的最大容量限制",
    "No favorites yet" : "还没有“我喜欢的”",
    "Files and folders you mark as favorite will show up here" : "收藏的文件和文件夹会在这里显示",
    "Shared with you" : "与您分享",
    "Shared with others" : "与他人分享",
    "Shared by link" : "通过链接分享",
    "Tags" : "标签",
    "Deleted files" : "已删除的文件",
    "Text file" : "文本文件",
    "New text file.txt" : "创建文本文件 .txt",
    "_{hours}:{minutes}:{seconds} hour left_::_{hours}:{minutes}:{seconds} hours left_" : ["剩余 {hours}:{minutes}:{seconds} 小时"],
    "{hours}:{minutes}h" : "{hours}:{minutes}",
    "_{minutes}:{seconds} minute left_::_{minutes}:{seconds} minutes left_" : ["剩余 {minutes}:{seconds} 分钟"],
    "{minutes}:{seconds}m" : "{minutes}:{seconds}",
    "_{seconds} second left_::_{seconds} seconds left_" : ["剩余 {seconds} 秒"],
    "{seconds}s" : "{seconds}s",
    "Any moment now..." : "现在任何时候...",
    "Soon..." : "很快...",
    "File upload is in progress. Leaving the page now will cancel the upload." : "文件正在上传中. 离开此页将会取消上传.",
    "Copy local link" : "复制本地链接",
    "Folder" : "文件夹",
    "Upload" : "上传",
    "No favorites" : "无收藏"
},
"nplurals=1; plural=0;");
